==> create-fly-1.21.10-6.0.8-5-sources.jar: com/zurrtum/create/infrastructure/packet/s2c/SignalEdgeGroupPacket.java <==
package com.zurrtum.create.infrastructure.packet.s2c;

import com.google.common.collect.ImmutableList;
import com.zurrtum.create.AllClientHandle;
import com.zurrtum.create.AllPackets;
import com.zurrtum.create.catnip.codecs.stream.CatnipStreamCodecBuilders;
import com.zurrtum.create.content.trains.signal.EdgeGroupColor;
import io.netty.buffer.ByteBuf;
import java.util.List;
import java.util.UUID;
import net.minecraft.class_2596;
import net.minecraft.class_2602;
import net.minecraft.class_4844;
import net.minecraft.class_9135;
import net.minecraft.class_9139;
import net.minecraft.class_9145;

public record SignalEdgeGroupPacket(List<UUID> ids, List<EdgeGroupColor> colors, boolean add) implements class_2596<class_2602> {
    public static final class_9139<ByteBuf, SignalEdgeGroupPacket> CODEC = class_9139.method_56436(
        CatnipStreamCodecBuilders.list(class_4844.field_48453),
        SignalEdgeGroupPacket::ids,
        CatnipStreamCodecBuilders.list(EdgeGroupColor.STREAM_CODEC),
        SignalEdgeGroupPacket::colors,
        class_9135.field_48547,
        SignalEdgeGroupPacket::add,
        SignalEdgeGroupPacket::new
    );

    public SignalEdgeGroupPacket(UUID id, EdgeGroupColor color) {
        this(ImmutableList.of(id), ImmutableList.of(color), true);
    }

    @Override
    public void apply(class_2602 listener) {
        AllClientHandle.INSTANCE.onSignalEdgeGroup(this);
    }

    @Override
    public class_9145<SignalEdgeGroupPacket> method_65080() {
        return AllPackets.SYNC_EDGE_GROUP;
    }
}

==> create-fly-1.21.11-6.0.8-2-sources.jar: com/zurrtum/create/infrastructure/packet/s2c/SignalEdgeGroupPacket.java <==
package com.zurrtum.create.infrastructure.packet.s2c;

import com.google.common.collect.ImmutableList;
import com.zurrtum.create.AllClientHandle;
import com.zurrtum.create.AllPackets;
import com.zurrtum.create.catnip.codecs.stream.CatnipStreamCodecBuilders;
import com.zurrtum.create.content.trains.signal.EdgeGroupColor;
import io.netty.buffer.ByteBuf;
import java.util.List;
import java.util.UUID;
import net.minecraft.class_2596;
import net.minecraft.class_2602;
import net.minecraft.class_4844;
import net.minecraft.class_9135;
import net.minecraft.class_9139;
import net.minecraft.class_9145;

public record SignalEdgeGroupPacket(List<UUID> ids, List<EdgeGroupColor> colors, boolean add) implements class_2596<class_2602> {
    public static final class_9139<ByteBuf, SignalEdgeGroupPacket> CODEC = class_9139.method_56436(
        CatnipStreamCodecBuilders.list(class_4844.field_48453),
        SignalEdgeGroupPacket::ids,
        CatnipStreamCodecBuilders.list(EdgeGroupColor.STREAM_CODEC),
        SignalEdgeGroupPacket::colors,
        class_9135.field_48547,
        SignalEdgeGroupPacket::add,
        SignalEdgeGroupPacket::new
    );

    public SignalEdgeGroupPacket(UUID id, EdgeGroupColor color) {
        this(ImmutableList.of(id), ImmutableList.of(color), true);
    }

    @Override
    public void handle(class_2602 listener) {
        AllClientHandle.INSTANCE.onSignalEdgeGroup(this);
    }

    @Override
    public class_9145<SignalEdgeGroupPacket> method_65080() {
        return AllPackets.SYNC_EDGE_GROUP;
    }
}
